<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>SnapTangential</name>
    <message>
        <location filename="../SnapTangentialInit.js" line="+2"/>
        <source>&amp;Tangential</source>
        <translation>正接</translation>
    </message>
</context>
</TS>
